from dataclasses import dataclass
from enum import Enum, unique

from asciiplot import asciiize
from rich.ansi import AnsiDecoder
from rich.console import RenderGroup
from rich.jupyter import JupyterMixin
from rich.layout import Layout
from rich.panel import Panel
from rich.text import Text

NO_DATA_AVAILABLE = Text("No data available", style="bold red")


def make_layout():
    layout = Layout(name="root")
    layout.split(
        Layout(name="header", size=3),
        Layout(name="main", ratio=1),
    )

    return layout


class BaseLayout:
    def __init__(self, base_layout, params=None):
        self.base_layout = base_layout
        self.params = params
        self.data = None


class Ui:
    def __init__(self, base_layout, layout, data_loader, layout_params=None):
        self.base_layout = base_layout
        self.layout = layout
        self.layout_params = layout_params
        self.data_loader = data_loader

    def refresh(self):
        return self.layout(self.base_layout(), self.layout_params).load(self.data_loader.fetch_data())


class EcsPanel(Panel):
    def __init__(self, *args, **kwargs):
        kwargs["style"] = "white on black"
        super().__init__(*args, **kwargs)


class AsciiPlotIntegration(JupyterMixin):
    def __init__(self, data):
        y_values, x_ticks = self._prepare_data(data)
        chart = asciiize(y_values, inter_points_margin=4, x_ticks=x_ticks)

        decoder = AnsiDecoder()
        self.rich_chart = RenderGroup(*decoder.decode(chart))

    def __rich_console__(self, console, options):
        yield self.rich_chart

    def _prepare_data(self, data):
        x_labels = []
        y_values = []
        for record in data:
            x_labels.append(record["Timestamp"].strftime("%H:%M"))
            y_values.append(round(record["Average"], 2))

        x_ticks = [" "] * len(x_labels)
        half = int(len(x_labels) / 2)
        x_ticks[0] = x_labels[0]
        x_ticks[half] = x_labels[half]
        x_ticks[-1] = x_labels[-1]

        return y_values, x_ticks


@dataclass
class StatusStyle:
    colour: str
    icon: str


@unique
class StatusEnum(Enum):
    ACTIVE = StatusStyle("green", "\u2B24")
    IN_PROGRESS = StatusStyle("yellow", "\u25D6")
    STOPPED = StatusStyle("red", "\u25CB")


class TaskLifecycleStatusEnum(Enum):
    RUNNING = StatusEnum.ACTIVE.value
    ACTIVATING = StatusEnum.IN_PROGRESS.value
    DEACTIVATING = StatusEnum.IN_PROGRESS.value
    PENDING = StatusEnum.IN_PROGRESS.value
    STOPPING = StatusEnum.IN_PROGRESS.value
    PROVISIONING = StatusEnum.IN_PROGRESS.value
    DEPROVISIONING = StatusEnum.IN_PROGRESS.value
    STOPPED = StatusEnum.STOPPED.value



import click

from .commands import dashboard, listing


@click.group(name="service")
def cli():
    """
    Service [listing, dashboard]
    """


cli.add_command(listing)
cli.add_command(dashboard)



import arrow

from ...context import ContextObject
from ...data_loader import fetch_listing as base_fetch_listing
from ...utils import _paginate


def _fetch_cloudwatch(cloudwatch, metrics_name, cluster_name, service_name):
    data = cloudwatch.get_metric_statistics(
        Namespace="AWS/ECS",
        MetricName=metrics_name,
        Dimensions=[
            {"Name": "ClusterName", "Value": cluster_name},
            {"Name": "ServiceName", "Value": service_name},
        ],
        StartTime=arrow.get().shift(hours=-24).datetime,
        EndTime=arrow.get().datetime,
        Period=3600,
        Statistics=["Average"],
    )
    return list(sorted(data["Datapoints"], key=lambda v: v["Timestamp"]))


def fetch_listing(context: ContextObject, click_params):
    return base_fetch_listing(
        context.ecs,
        paginator_type="list_services",
        arn_index="serviceArns",
        describe_function=context.ecs.describe_services,
        describe_filter="services",
        result_key="services",
        paginator_params={"cluster": click_params["cluster"]},
    )


def fetch_dashboard(context: ContextObject, click_params):
    services = context.ecs.describe_services(cluster=click_params["cluster"], services=[click_params["service"]])

    tasks_pagination = _paginate(
        context.ecs,
        "list_tasks",
        cluster=click_params["cluster"],
        desiredStatus="RUNNING",
        serviceName=click_params["service"],
    )

    arns = []
    for iterator in tasks_pagination:
        for task in iterator:
            arns += task["taskArns"]

    if not arns:
        return {"services": services}
    described_tasks = context.ecs.describe_tasks(cluster=click_params["cluster"], tasks=arns)

    cloudwatch_memory_data = _fetch_cloudwatch(
        context.cloudwatch,
        "MemoryUtilization",
        click_params["cluster"],
        click_params["service"],
    )
    cloudwatch_cpu_data = _fetch_cloudwatch(
        context.cloudwatch,
        "CPUUtilization",
        click_params["cluster"],
        click_params["service"],
    )

    task_definition = context.ecs.describe_task_definition(
        taskDefinition=described_tasks["tasks"][0]["taskDefinitionArn"]
    )

    log_configuration = task_definition["taskDefinition"]["containerDefinitions"][0]["logConfiguration"]
    describe_log_streams = context.logs.describe_log_streams(
        logGroupName=log_configuration["options"]["awslogs-group"],
        orderBy="LastEventTime",
        descending=True,
        limit=1,
    )
    log_events = context.logs.get_log_events(
        logGroupName=log_configuration["options"]["awslogs-group"],
        logStreamName=describe_log_streams["logStreams"][0]["logStreamName"],
        limit=100,
        startFromHead=False,
    )

    return {
        "services": services,
        "tasks": described_tasks,
        "cloudwatch_memory_data": cloudwatch_memory_data,
        "cloudwatch_cpu_data": cloudwatch_cpu_data,
        "logs": log_events,
    }



from ...context import ContextObject
from ...data_loader import fetch_listing as base_fetch_listing


def fetch_listing(context: ContextObject, click_params):
    return base_fetch_listing(
        context.ecs,
        paginator_type="list_clusters",
        arn_index="clusterArns",
        describe_function=context.ecs.describe_clusters,
        describe_filter="clusters",
        result_key="clusters",
    )



from time import sleep

from rich.console import Console
from rich.live import Live


class Runner:
    def __init__(self, ui):
        self.ui = ui

    def run(self):
        console = Console()
        console.print(self.ui.refresh())


class LiveRunner:
    def __init__(self, ui):
        self.ui = ui

    def until(self, call=lambda: True):
        return call

    def run(self):
        with Live(self.ui.refresh(), refresh_per_second=0.1) as live:
            while self.until():
                sleep(0.1)
                live.update(self.ui.refresh())



import os

import boto3


class ContextObject:
    def __init__(self):
        self._ecs = boto3.client("ecs")
        self._cloudwatch = boto3.client("cloudwatch")
        self._logs = boto3.client("logs")

    @property
    def ecs(self):
        return self._ecs

    @property
    def cloudwatch(self):
        return self._cloudwatch

    @property
    def logs(self):
        return self._logs

    @property
    def aws_region(self):
        return os.environ.get("AWS_REGION", os.environ.get("AWS_DEFAULT_REGION"))

    @property
    def aws_account_id(self):
        return boto3.client("sts").get_caller_identity().get("Account")



from enum import Enum

from rich.table import Table

from ...ui import BaseLayout, EcsPanel, StatusEnum


class ClusterStatusEnum(Enum):
    ACTIVE = StatusEnum.ACTIVE.value
    PROVISIONING = StatusEnum.IN_PROGRESS.value
    DEPROVISIONING = StatusEnum.IN_PROGRESS.value
    FAILED = StatusEnum.STOPPED.value
    INACTIVE = StatusEnum.STOPPED.value


class ListingLayout(BaseLayout):
    def header(self):
        grid = Table.grid(expand=True)
        grid.add_column(justify="left", ratio=1)
        grid.add_row(f"Clusters")

        return EcsPanel(grid)

    def main(self):
        table = Table()

        table.add_column("Cluster name")
        table.add_column("Status")
        table.add_column("Running tasks")
        table.add_column("Pending tasks")
        table.add_column("Active services")

        for cluster in self.data.fetcher:
            status = ClusterStatusEnum[cluster["status"]].value

            table.add_row(
                cluster["clusterName"],
                f"[{status.colour}]{status.icon}[/{status.colour}]  ({cluster['status'].lower()})",
                str(cluster["runningTasksCount"]),
                str(cluster["pendingTasksCount"]),
                str(cluster["activeServicesCount"]),
            )

        return table

    def load(self, data):
        self.data = data
        self.base_layout["header"].update(self.header())
        self.base_layout["main"].update(self.main())

        return self.base_layout



from dataclasses import dataclass

from .context import ContextObject
from .utils import _paginate, grouper


@dataclass
class Data:
    click_params: dict
    fetcher: dict


class DataLoader:
    def __init__(self, context: ContextObject, data_fetcher, click_params=None):
        self.context = context
        self.data_fetcher = data_fetcher
        self.click_params = click_params

    def fetch_data(self):
        return Data(self.click_params, self.data_fetcher(self.context, self.click_params))


def fetch_listing(
    ecs,
    paginator_type,
    arn_index,
    describe_function,
    describe_filter,
    result_key,
    grouper_limit=10,
    paginator_params=None,
):
    if not paginator_params:
        paginator_params = {}

    pagination = _paginate(
        ecs,
        paginator_type,
        **paginator_params,
    )

    arns = []
    for iterator in pagination:
        for task in iterator:
            arns.extend(task[arn_index])

    result = []
    for chunk in grouper(arns, grouper_limit):
        params = {**{describe_filter: list(filter(None, chunk)), **paginator_params}}
        result.extend(describe_function(**params)[result_key])

    return result



import click

from ...data_loader import DataLoader
from ...runner import LiveRunner
from ...ui import Ui, make_layout
from .data import fetch_run_task, fetch_task
from .layouts import TaskLayout


@click.command(help="Run task")
@click.option("--cluster", default="main", type=str)
@click.option("--network-configuration", required=False, type=str)
@click.option("--capacity-provider-strategy", required=False, type=str)
@click.argument("task-definition", required=True, type=str)
@click.argument("command", nargs=-1)
@click.pass_context
def run(ctx, **kwargs):
    LiveRunner(
        Ui(make_layout, TaskLayout, DataLoader(ctx.obj, fetch_run_task, kwargs), {"header_title": "Task > Run"})
    ).run()


@click.command(help="Show information about ran task")
@click.option("--cluster", default="main", type=str)
@click.argument("task-id", required=True, type=str)
@click.pass_context
def show(ctx, **kwargs):
    LiveRunner(Ui(make_layout, TaskLayout, DataLoader(ctx.obj, fetch_task, kwargs), {"header_title": "Task"})).run()



import click

from ...data_loader import DataLoader
from ...runner import LiveRunner, Runner
from ...ui import Ui, make_layout
from .data import fetch_dashboard, fetch_listing
from .layouts import DashboardLayout, ListingLayout


@click.command(help="List available services", name="list")
@click.option("--cluster", default="main")
@click.pass_context
def listing(ctx, **kwargs):
    Runner(Ui(make_layout, ListingLayout, DataLoader(ctx.obj, fetch_listing, kwargs))).run()


@click.command(help="Dashboard of service")
@click.argument("service")
@click.option("--cluster", default="main")
@click.pass_context
def dashboard(ctx, **kwargs):
    LiveRunner(
        Ui(
            make_layout,
            DashboardLayout,
            DataLoader(ctx.obj, fetch_dashboard, kwargs),
        )
    ).run()



import click

from ...data_loader import DataLoader
from ...plugins.cluster.data import fetch_listing
from ...plugins.cluster.layouts import ListingLayout
from ...runner import Runner
from ...ui import Ui, make_layout


@click.command(help="List available clusters", name="list")
@click.pass_context
def listing(ctx):
    Runner(Ui(make_layout, ListingLayout, DataLoader(ctx.obj, fetch_listing))).run()



import json

from ...context import ContextObject
from ...exception import EcsToolException


def _fetch_latest_active_task_definition(ecs_client, name):
    response = ecs_client.list_task_definitions(familyPrefix=name, status="ACTIVE", sort="DESC", maxResults=1)

    if not response["taskDefinitionArns"]:
        raise EcsToolException(f'Unable to find active task definition with name "{name}".')

    return response["taskDefinitionArns"][0].rsplit(":", 1)[0]


def _fetch_task(ecs, logs, cluster: str, task_arn: str):
    described_task = ecs.describe_tasks(cluster=cluster, tasks=[task_arn])["tasks"][0]

    task_definition = ecs.describe_task_definition(taskDefinition=described_task["taskDefinitionArn"])

    log_configuration = task_definition["taskDefinition"]["containerDefinitions"][0]["logConfiguration"]
    describe_log_streams = logs.describe_log_streams(
        logGroupName=log_configuration["options"]["awslogs-group"],
        orderBy="LastEventTime",
        descending=True,
        limit=1,
    )
    log_events = logs.get_log_events(
        logGroupName=log_configuration["options"]["awslogs-group"],
        logStreamName=describe_log_streams["logStreams"][0]["logStreamName"],
        limit=100,
        startFromHead=False,
    )

    return {"task": described_task, "task_definition": task_definition["taskDefinition"], "logs": log_events}


def fetch_task(context: ContextObject, click_params):
    task_arn = f"arn:aws:ecs:{context.aws_region}:{context.aws_account_id}:task/{click_params['cluster']}/{click_params['task_id']}"
    return _fetch_task(context.ecs, context.logs, click_params["cluster"], task_arn)


def fetch_run_task(context: ContextObject, click_params):
    if not getattr(fetch_run_task, "task_ran", False):
        args = {"cluster": click_params["cluster"]}

        try:
            _, _ = click_params["task_definition"].split(":")
            args["taskDefinition"] = click_params["task_definition"]
        except ValueError:
            args["taskDefinition"] = _fetch_latest_active_task_definition(context.ecs, click_params["task_definition"])

        if click_params["command"]:
            args["overrides"] = {
                "containerOverrides": [
                    {"name": args["taskDefinition"].rsplit("/")[1], "command": click_params["command"]}
                ]
            }

        if click_params["capacity_provider_strategy"]:
            args["capacityProviderStrategy"] = [json.loads(click_params["capacity_provider_strategy"])]

        if click_params["network_configuration"]:
            args["networkConfiguration"] = json.loads(click_params["network_configuration"])

        result = context.ecs.run_task(**args)

        fetch_run_task.task_ran = True
        fetch_run_task.task_arn = result["tasks"][0]["taskArn"]

    return _fetch_task(context.ecs, context.logs, click_params["cluster"], fetch_run_task.task_arn)



import arrow
from rich.layout import Layout
from rich.table import Table

from ... import DATE_FORMAT
from ...ui import BaseLayout, EcsPanel, TaskLifecycleStatusEnum


class TaskLayout(BaseLayout):
    def header(self):
        grid = Table.grid(expand=True)
        grid.add_column(justify="left", ratio=1)
        grid.add_column(justify="right")
        title = f"Clusters > {self.data.click_params['cluster']} > {self.params['header_title']} > {self.data.fetcher['task_definition']['taskDefinitionArn'].rsplit('/')[1]} > {self.data.fetcher['task']['taskArn'].rsplit('/')[2]}"
        grid.add_row(title)

        return EcsPanel(grid)

    def main_left(self):
        grid = Table.grid()
        grid.add_column()
        grid.add_column()

        status = TaskLifecycleStatusEnum[self.data.fetcher["task"]["lastStatus"]].value

        grid.add_row(
            "Status: ",
            f"[{status.colour}]{status.icon}[/{status.colour}]  ({self.data.fetcher['task']['lastStatus'].lower()})",
        )
        grid.add_row(
            "Definition: ",
            self.data.fetcher["task"]["taskDefinitionArn"].rsplit("/")[1],
        )
        if self.data.fetcher["task"].get("startedAt"):
            label = "Started At: "
            key = "startedAt"
        else:
            label = "Created At: "
            key = "createdAt"
        grid.add_row(
            label,
            arrow.get(self.data.fetcher["task"][key]).format(DATE_FORMAT),
        )
        grid.add_row("Memory: ", self.data.fetcher["task"]["memory"])
        grid.add_row("CPU: ", self.data.fetcher["task"]["cpu"])

        return EcsPanel(grid, title="Basic info")

    def main_right(self):
        grid = Table.grid()
        grid.add_column()

        for event in self.data.fetcher["logs"]["events"]:
            grid.add_row(event["message"])

        return EcsPanel(grid, title="Last logs")

    def load(self, data):
        self.data = data
        self.base_layout["header"].update(self.header())

        self.base_layout["main"].split_row(
            Layout(name="main_left"),
            Layout(name="main_right", ratio=2, minimum_size=60),
        )

        self.base_layout["main_left"].update(self.main_left())
        self.base_layout["main_right"].update(self.main_right())

        return self.base_layout



from enum import Enum, unique

import arrow
from rich.layout import Layout
from rich.table import Table

from ... import DATE_FORMAT
from ...ui import NO_DATA_AVAILABLE, AsciiPlotIntegration, BaseLayout, EcsPanel, StatusEnum, TaskLifecycleStatusEnum


@unique
class ServiceStatusEnum(Enum):
    ACTIVE = StatusEnum.ACTIVE.value
    DRAINING = StatusEnum.IN_PROGRESS.value
    INACTIVE = StatusEnum.STOPPED.value


class DashboardLayout(BaseLayout):
    def header(self):
        grid = Table.grid(expand=True)
        grid.add_column(justify="left", ratio=1)
        grid.add_column(justify="right")
        grid.add_row(
            f"Clusters > {self.data.click_params['cluster']} > Services > {self.data.click_params['service']}",
            self.data.fetcher["services"]["ResponseMetadata"]["HTTPHeaders"]["date"],
        )
        return EcsPanel(grid)

    def basic_info(self):
        service = self.data.fetcher["services"]["services"][0]
        status = ServiceStatusEnum[service["status"]].value

        grid = Table.grid()
        grid.add_column()
        grid.add_column()
        grid.add_row(
            "Status: ",
            f"[{status.colour}]{status.icon}[/{status.colour}]  ({service['status'].lower()})",
        )
        grid.add_row("Type: ", f"{service['schedulingStrategy']}")
        grid.add_row("Launch: ", f"{service['launchType']}")
        grid.add_row(
            "Tasks: ",
            f"{service['runningCount']}/{service['desiredCount']} ({service['pendingCount']} pending)",
        )
        if "deployments" in service:
            deployment_primary = None
            deployment_active = None
            for deployment in service["deployments"]:
                if deployment["status"] == "PRIMARY":
                    deployment_primary = arrow.get(deployment["updatedAt"])

                if deployment["status"] == "ACTIVE":
                    deployment_active = arrow.get(deployment["createdAt"])

            if not deployment_active:
                deployment_status = f"Completed at {deployment_primary.format(DATE_FORMAT)}"
            else:
                deployment_status = f"Running from {deployment_active.format(DATE_FORMAT)}"

            grid.add_row("Deployment: ", deployment_status)

        return EcsPanel(grid, title="Basic info")

    def tasks(self):
        if not self.data.fetcher.get("tasks"):
            return EcsPanel(NO_DATA_AVAILABLE, title="Tasks")

        grid = Table.grid()
        grid.add_column()
        grid.add_column()

        for task in self.data.fetcher["tasks"]["tasks"]:
            status = TaskLifecycleStatusEnum[task["lastStatus"]].value
            grid.add_row(
                task["taskArn"].split("/")[-1][:8] + "... ",
                f"[{status.colour}]{status.icon}[/{status.colour}]  ({task['lastStatus'].lower()})",
            )

        return EcsPanel(grid, title="Tasks")

    def memory(self):
        content = (
            AsciiPlotIntegration(self.data.fetcher["cloudwatch_memory_data"])
            if self.data.fetcher.get("cloudwatch_memory_data")
            else NO_DATA_AVAILABLE
        )
        return EcsPanel(
            content,
            title="MemoryUtilization",
        )

    def cpu(self):
        content = (
            AsciiPlotIntegration(self.data.fetcher["cloudwatch_cpu_data"])
            if self.data.fetcher.get("cloudwatch_cpu_data")
            else NO_DATA_AVAILABLE
        )
        return EcsPanel(
            content,
            title="CPUUtilization",
        )

    def logs(self):
        if not self.data.fetcher.get("logs"):
            return EcsPanel(NO_DATA_AVAILABLE, title="Last logs")

        grid = Table.grid()
        grid.add_column()

        for event in self.data.fetcher["logs"]["events"]:
            grid.add_row(event["message"])

        return EcsPanel(grid, title="Last logs")

    def load(self, data):
        self.data = data
        self.base_layout["header"].update(self.header())

        self.base_layout["main"].split_row(
            Layout(name="main_left"),
            Layout(name="main_right", ratio=2, minimum_size=60),
        )
        self.base_layout["main_left"].split(
            Layout(name="main_left_basic_info"),
            Layout(name="main_left_tasks"),
        )
        self.base_layout["main_right"].split(
            Layout(name="main_right_top"),
            Layout(name="main_right_bottom"),
        )
        self.base_layout["main_right_top"].split(
            Layout(name="main_right_top_cpu"),
            Layout(name="main_right_top_memory"),
        )

        self.base_layout["main_left_basic_info"].update(self.basic_info())
        self.base_layout["main_left_tasks"].update(self.tasks())

        self.base_layout["main_right_top_memory"].update(self.memory())
        self.base_layout["main_right_top_cpu"].update(self.cpu())

        self.base_layout["main_right_bottom"].update(self.logs())

        return self.base_layout


class ListingLayout(BaseLayout):
    def header(self):
        grid = Table.grid(expand=True)
        grid.add_column(justify="left", ratio=1)
        grid.add_row(f"Clusters > {self.data.click_params['cluster']} > Services")

        return EcsPanel(grid)

    def main(self):
        table = Table()

        table.add_column("Service name")
        table.add_column("Task definition")
        table.add_column("Status")
        table.add_column("Tasks")
        table.add_column("Service type")
        table.add_column("Launch type")

        for service in self.data.fetcher:
            status = ServiceStatusEnum[service["status"]].value
            table.add_row(
                service["serviceName"],
                service["taskDefinition"].rsplit("task-definition/", 1)[-1],
                f"[{status.colour}]{status.icon}[/{status.colour}]  ({service['status'].lower()})",
                f"{service['runningCount']}/{service['desiredCount']} ({service['pendingCount']} pending)",
                service["schedulingStrategy"],
                service["launchType"],
            )

        return table

    def load(self, data):
        self.data = data
        self.base_layout["header"].update(self.header())
        self.base_layout["main"].update(self.main())

        return self.base_layout



from itertools import zip_longest


def _paginate(ecs_client, service, **kwargs):
    kwargs = {k: v for k, v in kwargs.items() if v is not None}
    paginator = ecs_client.get_paginator(service)
    pagination_config = {"MaxItems": 100, "PageSize": 100}

    resp = paginator.paginate(**kwargs, PaginationConfig=pagination_config)
    yield resp

    while "NextToken" in resp:
        yield paginator.paginate(
            {
                **kwargs,
                **{"PaginationConfig": pagination_config},
                **{"StartingToken": resp["NextToken"]},
            }
        )


def grouper(iterable, n, fillvalue=None):
    """
    Collect data into fixed-length chunks or blocks
    https://docs.python.org/3/library/itertools.html
    """
    # grouper('ABCDEFG', 3, 'x') --> ABC DEF Gxx"
    args = [iter(iterable)] * n
    return zip_longest(*args, fillvalue=fillvalue)



import click
from rich.console import Console

from .context import ContextObject
from .exception import EcsToolException
from .plugins import cluster, service, task


@click.group()
@click.pass_context
def cli(ctx):
    ctx.obj = ContextObject()


def safe_cli():
    """
    Used as an entry point in pyproject.toml::tool.poetry.scripts
    To handle global exceptions.
    """
    console = Console()
    try:
        cli()
    except EcsToolException as e:
        console.print(e.message, style="bold red")
        return
    except Exception as e:
        if type(e).__qualname__ == "ClusterNotFoundException":
            # Handle botocore.errorfactory.ClusterNotFoundException exception
            console.print(
                "Cluster not found. To list available clusters run: ecs cluster list",
                style="bold red",
            )
            return
        if type(e).__qualname__ == "ServiceNotFoundException":
            # handle botocore.errorfactory.ServiceNotFoundException
            console.print(
                "Service not found in this cluster. To list available services run: ecs service list",
                style="bold red",
            )
            return

        raise


cli.add_command(cluster.cli)
cli.add_command(service.cli)
cli.add_command(task.cli)


if __name__ == "__main__":
    cli()



# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['ecs_tool',
 'ecs_tool.plugins',
 'ecs_tool.plugins.cluster',
 'ecs_tool.plugins.service',
 'ecs_tool.plugins.task']

package_data = \
{'': ['*']}

install_requires = \
['arrow>=1.1.0,<2.0.0',
 'asciiplot>=0.1.1,<0.2.0',
 'boto3>=1.9,<2.0',
 'click-log>=0.3.2,<0.4.0',
 'click>=8.0,<9.0',
 'loguru>=0.5.3,<0.6.0',
 'rich>=10.3.0,<11.0.0']

entry_points = \
{'console_scripts': ['ecs = ecs_tool.cli:safe_cli']}

setup_kwargs = {
    'name': 'ecs-tool',
    'version': '0.10.1',
    'description': 'ecs-tool tries to eliminate common caveats for your day-to-day work with Elastic Container Service (ECS).',
    'long_description': '# ECS Tool\n[![PyPI](https://img.shields.io/pypi/v/ecs-tool.svg)](https://pypi.org/project/ecs-tool/) ![](https://img.shields.io/pypi/pyversions/ecs-tool.svg) ![](https://img.shields.io/pypi/l/ecs-tool.svg)\n\n[aws-ecs](https://docs.aws.amazon.com/cli/latest/reference/ecs/index.html) on steroids.\n\necs-tool tries to eliminate common caveats for your day-to-day work with Elastic Container Service (ECS).\n\nDashboards with important information about your services, more intuitive CLI interface and more.\n\n### New version (`0.10`) is still in Beta.\n\n## Screenshots\n<a href="https://user-images.githubusercontent.com/164009/127609861-145265c3-5b1a-4ed2-a55b-2d400f7b0975.png" title="Dashboard"><img width="150" alt="Dashboard" src="https://user-images.githubusercontent.com/164009/127609795-ac1a5684-a334-418b-932f-15880bfe7066.png"></a>\n<a href="https://user-images.githubusercontent.com/164009/127610177-ca44d337-a2a3-469b-b413-8221e9c4598e.png" title="Cluster listing"><img width="150" alt="Cluster listing" src="https://user-images.githubusercontent.com/164009/127610175-c3ebd211-dc65-4770-8f69-360c1fb5bf89.png"></a>\n<a href="https://user-images.githubusercontent.com/164009/127610437-3d2f153e-7554-4284-9454-cfed8e2a3ac8.png" title="Serices list"><img width="150" alt="Services list" src="https://user-images.githubusercontent.com/164009/127610439-e8d0b543-3062-47c8-918f-4edd30bdf6eb.png"></a>\n\n## Summary of functionalities\n### Cluster\n* <a href="https://user-images.githubusercontent.com/164009/127610177-ca44d337-a2a3-469b-b413-8221e9c4598e.png">Listing of all clusters</a>\n### Service\n* <a href="https://user-images.githubusercontent.com/164009/127610437-3d2f153e-7554-4284-9454-cfed8e2a3ac8.png">Listing of all services</a>\n* <a href="https://user-images.githubusercontent.com/164009/127609861-145265c3-5b1a-4ed2-a55b-2d400f7b0975.png">Dashboard</a>, which includes `CPUUtilization` and `MemoryUtilization` plots for service (refreshed automatically)\n### Task\n* Run task, returns information about ran task, e.g. logs output from it (refreshed automatically)\n* Show task, displays information about running task (refreshed automatically)\n\nMore detailed information about available commands below.\n\n## Installation & usage\n\n### As python package\n```shell\npip install ecs-tool\n\necs\n\n# with aws-vault\naws-vault exec my-aws-profile -- ecs \n```\n\n### With docker\n```shell\n# build image\ndocker build -t ecs-tool\n\ndocker run -it --rm --name ecs-tool ecs-tool ecs\n\n# with aws-vault\ndocker run -it --rm --env-file <(aws-vault exec my-aws-profile -- env | grep "^AWS_") --name ecs-tool ecs-tool ecs\n```\n\n## What `ecs-tool` can do?\n\n### Cluster\n### List of available clusters\n```shell\necs cluster list\n```\n\n### Service\n### List of available services\n```shell\necs service list [OPTIONS]\n\nOptions:\n  --cluster TEXT\n```\n\n### Dashboard for service\n```shell\necs service dashboard [OPTIONS] SERVICE\n\nOptions:\n  --cluster TEXT\n```\n\n### Task\n### Run task\n```shell\necs task run [OPTIONS] TASK_DEFINITION [COMMAND]...\n\nOptions:\n  --cluster TEXT\n  --network-configuration TEXT\n  --capacity-provider-strategy TEXT\n```\n\n`TASK_DEFINITION` - you can either provide full definition e.g. `my-definition:123` or just name, `my-definition`. If no number is provided, latest version is assumed.\n\n`[COMMAND]` - any command that should be executed on ECS task\n\nExamples:\n\n**Running with Fargate**\n```shell\necs task run epsy-dynks --capacity-provider-strategy \'{"capacityProvider": "FARGATE"}\' --network-configuration \'{"awsvpcConfiguration":{"subnets":["subnet-1234567890"],"securityGroups":["sg-123456789"],"assignPublicIp":"DISABLED"}}\' --  my_command subcommand --one-option --another-option="test"\n```\n\n### Display information about ran task\n```shell\necs task show [OPTIONS] TASK_ID\n\nOptions:\n  --cluster TEXT\n```\n\n## Can I use grep?\nYes! All commands results (but dashboards) can be filtered with `grep`\n',
    'author': 'Daniel Ancuta',
    'author_email': 'whisller@gmail.com',
    'maintainer': None,
    'maintainer_email': None,
    'url': 'https://github.com/whisller/ecs-tool',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'entry_points': entry_points,
    'python_requires': '>=3.8,<4.0',
}


setup(**setup_kwargs)
